<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Праћење Система</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Праћење Система је алат за надзирање оптерећења система у реалном времену и управљање системским процесима и услугама.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Сакриј детаље</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Читање</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Уписивање</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 секунди</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 дана %2 сат. %3 мин.</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Употреба</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Тренутни радни такт</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Радни такт</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Произвиђач</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Лежишта</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Логички процесори</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Виртуелизација</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1i кеш</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1d кеш</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2 кеш</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3 кеш</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Просечно оптерећање</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Дескриптори датотека</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Процеси</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Нити</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Име домаћина</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Врста ОС-а</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Верзија</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Време у раду</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 секунди</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Нема резултата претраге</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Детаљи</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Детаљи</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>активно</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>учитавање</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>неактивно</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>отказао</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>активирање</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>деактивирање</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>није-пронађено</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>лоше-подешено</translation>
    </message>
    <message>
        <source>error</source>
        <translation>грешка</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>спојено</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>маскирано</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>учитавање</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>Н/П</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Ауто.</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ручно</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>омогућено</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>онемогућено</translation>
    </message>
    <message>
        <source>static</source>
        <translation>статично</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>несталан</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>индиректно</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>омогућено-извршавање</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>маскирано</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>генерисано</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>мртво</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>start-pre</translation>
    </message>
    <message>
        <source>start</source>
        <translation>start</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>ради</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>изашао</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>reload</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>stop</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>отказао</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>auto-restart</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Заузето</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Слободно</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Дељено</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Кеширано</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Попуне</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Кеширана помоћна мем.</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активно</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Неактивно</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Прљаво</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Пресликано</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Укупна помоћна мем.</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Слободна помоћна мем.</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Плоча</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Модел</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Брзина читања</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Брзина уписивања</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Капацитет</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Читања сектора</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Читања/сек</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Читања сектора/сек</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Читања спојено/сек</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Уписаних сектора</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Завршених уписивања </translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Уписивања спојено </translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Уписивања/сек</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Уписаних сектора/сек</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Читања спојено/сек</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>У реду</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Систем</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Прикажи пречице</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Окончање овог процеса може изазвати губитак података.
Заиста желите да наставите?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Окончај процес</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Принудно окончање овог процеса може изазвати губитак података.
Заиста желите да наставите?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Принудно окончање овог програма може изазвати губитак података.
Заиста желите да наставите?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Принудно окончај</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Окончај</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Подешавање</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Величина</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>ИП адреса:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Мрежна маска:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Емитовање:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Префикслен:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Опсег:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Врста везе</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ЕССИД</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Квалитет везе</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Јачина сигнала</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Ниво шума</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>МАК</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Пропусни опсег</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>RX пакети</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>RX бајтови</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>RX грешке</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX одбачено</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>RX прекорачења</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>RX оквир</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>TX пакети</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>TX бајтови</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>TX грешке</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>TX прекорачења</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>TX носилац</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>ИПв4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>ИПв6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX одбачено</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Командна линија</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Почетно време</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Кликните на програм који желите да окончате</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Меморија</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Примање</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>ЦПЈ</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Читање диска</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Уписивање диска</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Меморија</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Помоћна</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Није омогућено</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Преузимање</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Отпремање</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Преузето</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Отпремљено</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Слање</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Дискови</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Веома висок</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Висок</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Нормалан</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Низак</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Веома низак</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Прилагођен</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Неважеће</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>ПИД: %1, Грешка: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Неуспешна промена приоритета процеса</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Програми</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Моји процеси</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Сви процеси</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Неуспешно паузирање процеса</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Неуспешно настављање процеса</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Убијање процеса није успело</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Непозната грешка</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Неуспешно слање сигнала ка процесу</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Окончавање процеса није успело</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 програм/а %2 процес/а у раду)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Нема одговора</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Обустављено</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Касета</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Прикажи локацију команде</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Својства</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Окончај процес</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Настави процес</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Убиј процес</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Промени приоритет</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Обустави процес</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Прилагођени приоритет</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Промени</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>ЦПЈ</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Меморија</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Уписивање диска</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Читање диска</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Преузимање</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Отпремање</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>ПИД</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Корисник</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Приоритет</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Дељена меморија</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Виртуелна меморија</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Неподржано</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавање</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Заштита система</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Обавештења</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Неуспешна поставка режима покретања услуге</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Грешка: Неуспешна поставка режима покретања услуге због отказа под-процеса</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Назив инстанце услуге</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>У реду</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Освежи</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Покрени</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Заустави</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Ауто.</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ручно</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Режим покретања</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Учитај</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активност</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Подстање</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Стање</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>ПИД</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Режим покретања</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Подешавање</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Принудно окончај програм</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Проширено</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Збијено</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Приказ</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Процеси</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Услуге</translation>
    </message>
</context>
</TS>
